@@ -58,7 +58,16 @@ public:
      */
     qreal preferredColumnWidth(const QByteArray& role) const;
 
+    /**
+     * Sets the width of the column *before* the first column.
+     * This is intended to facilitate an empty region for deselection in the main viewport.
+     */
+    void setLeadingPadding(qreal width);
+    qreal leadingPadding() const;
+
 Q_SIGNALS:
+    void leadingPaddingChanged(qreal width);
+
     /**
      * Is emitted if the width of a column has been adjusted by the user with the mouse
      * (no signal is emitted if KItemListHeader::setColumnWidth() is invoked).
